@@ -96,14 +96,12 @@ subsemble <- function(x, y, newx = NULL, family = gaussian(),
     if (inherits(parallel, "character")) {
       if (!(parallel %in% c("seq","multicore"))) {
         stop("'parallel' must be either 'seq' or 'multicore' or a snow cluster object")
-      }
+      } else if (parallel == "multicore") {
+        ncores <- detectCores()
+      } 
     } else if (!inherits(parallel, "cluster")) {
         stop("'parallel' must be either 'seq' or 'multicore' or a snow cluster object")
     }
-    if (parallel!="seq"){
-        require(parallel)
-        ncores <- detectCores()
-    }
     
             
     # For each J subset, assign indices to CV folds, such that each fold contains ~N/J points
@@ -163,7 +161,7 @@ subsemble <- function(x, y, newx = NULL, family = gaussian(),
         cvRes <- sapply(X=1:V, FUN=.cvFun, subCVsets=subCVsets, y=y, xmat=x, family=family,
                         learner=learner, obsWeights=obsWeights, seed=seed)  #cvRes is a J x V matrix
       }
-      if (class(cvRes)!="matrix") {
+      if (!inherits(cvRes, "matrix")) {
         cvRes <- t(as.matrix(cvRes))
       } 
       Z <- as.data.frame(sapply(1:J, .subPreds, cvRes=cvRes))
